@@ -3,7 +3,7 @@ import datetime
 import decimal
 from copy import copy
 from functools import partial
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Set, Tuple, Type, Union
+from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Set, Tuple, Type, Union, cast
 
 from pypika import JoinType, Parameter, Query, Table
 
@@ -13,6 +13,7 @@ from tortoise.fields.relational import (
     BackwardFKRelation,
     BackwardOneToOneRelation,
     ManyToManyFieldInstance,
+    RelationalField,
 )
 from tortoise.query_utils import QueryModifier
 
@@ -45,7 +46,7 @@ class BaseExecutor:
         self.prefetch_map = prefetch_map or {}
         self._prefetch_queries = prefetch_queries or {}
 
-        key = f"{self.db.connection_name}:{self.model._meta.table}"
+        key = f"{self.db.connection_name}:{self.model._meta.db_table}"
         if key not in EXECUTOR_CACHE:
             self.regular_columns, columns = self._prepare_insert_columns()
             self.insert_query = self._prepare_insert_statement(columns)
@@ -56,7 +57,7 @@ class BaseExecutor:
                     include_generated=True
                 )
                 self.insert_query_all = self._prepare_insert_statement(
-                    columns_all, no_generated=True
+                    columns_all, has_generated=False
                 )
 
             self.column_map: Dict[str, Callable[[Any, Any], Any]] = {}
@@ -72,7 +73,7 @@ class BaseExecutor:
             table = self.model._meta.basetable
             self.delete_query = str(
                 self.model._meta.basequery.where(
-                    table[self.model._meta.db_pk_field] == self.Parameter(0)
+                    table[self.model._meta.db_pk_column] == self.parameter(0)
                 ).delete()
             )
             self.update_cache: Dict[str, str] = {}
@@ -86,6 +87,7 @@ class BaseExecutor:
                 self.delete_query,
                 self.update_cache,
             )
+
         else:
             (
                 self.regular_columns,
@@ -132,42 +134,43 @@ class BaseExecutor:
             return cls.TO_DB_OVERRIDE[field_object.__class__](field_object, attr, instance)
         return field_object.to_db_value(attr, instance)
 
-    def _prepare_insert_statement(self, columns: List[str], no_generated: bool = False) -> str:
+    def _prepare_insert_statement(self, columns: List[str], has_generated: bool = True) -> str:
         # Insert should implement returning new id to saved object
         # Each db has it's own methods for it, so each implementation should
         # go to descendant executors
         return str(
             self.db.query_class.into(self.model._meta.basetable)
             .columns(*columns)
-            .insert(*[self.Parameter(i) for i in range(len(columns))])
+            .insert(*[self.parameter(i) for i in range(len(columns))])
         )
 
     async def _process_insert_result(self, instance: "Model", results: Any) -> None:
         raise NotImplementedError()  # pragma: nocoverage
 
-    def Parameter(self, pos: int) -> Parameter:
+    def parameter(self, pos: int) -> Parameter:
         raise NotImplementedError()  # pragma: nocoverage
 
     async def execute_insert(self, instance: "Model") -> None:
         if not instance._custom_generated_pk:
             values = [
-                self.column_map[column](getattr(instance, column), instance)
-                for column in self.regular_columns
+                self.column_map[field_name](getattr(instance, field_name), instance)
+                for field_name in self.regular_columns
             ]
             insert_result = await self.db.execute_insert(self.insert_query, values)
             await self._process_insert_result(instance, insert_result)
+
         else:
             values = [
-                self.column_map[column](getattr(instance, column), instance)
-                for column in self.regular_columns_all
+                self.column_map[field_name](getattr(instance, field_name), instance)
+                for field_name in self.regular_columns_all
             ]
             await self.db.execute_insert(self.insert_query_all, values)
 
     async def execute_bulk_insert(self, instances: "List[Model]") -> None:
         values_lists = [
             [
-                self.column_map[column](getattr(instance, column), instance)
-                for column in self.regular_columns
+                self.column_map[field_name](getattr(instance, field_name), instance)
+                for field_name in self.regular_columns
             ]
             for instance in instances
         ]
@@ -186,13 +189,13 @@ class BaseExecutor:
         query = self.db.query_class.update(table)
         count = 0
         for field in update_fields or self.model._meta.fields_db_projection.keys():
-            db_field = self.model._meta.fields_db_projection[field]
+            db_column = self.model._meta.fields_db_projection[field]
             field_object = self.model._meta.fields_map[field]
             if not field_object.pk:
-                query = query.set(db_field, self.Parameter(count))
+                query = query.set(db_column, self.parameter(count))
                 count += 1
 
-        query = query.where(table[self.model._meta.db_pk_field] == self.Parameter(count))
+        query = query.where(table[self.model._meta.db_pk_column] == self.parameter(count))
 
         sql = self.update_cache[key] = query.get_sql()
         return sql
@@ -316,7 +319,7 @@ class BaseExecutor:
         )
 
         related_query_table = related_query.model._meta.basetable
-        related_pk_field = related_query.model._meta.db_pk_field
+        related_pk_field = related_query.model._meta.db_pk_column
         related_query.resolve_ordering(related_query.model, related_query_table, [], {})
         query = (
             related_query.query.join(subquery)
@@ -355,7 +358,7 @@ class BaseExecutor:
         relations = [
             (
                 self.model._meta.pk.to_python_value(e["_backward_relation_key"]),
-                field_object.model_class._meta.pk.to_python_value(e[related_pk_field]),
+                field_object.related_model._meta.pk.to_python_value(e[related_pk_field]),
             )
             for e in raw_results
         ]
@@ -383,7 +386,7 @@ class BaseExecutor:
         relation_key_field = f"{field}_id"
         for instance in instance_list:
             if getattr(instance, relation_key_field):
-                key = instance._meta.fields_map[relation_key_field].model_field_name
+                key = cast(RelationalField, instance._meta.fields_map[field]).to_field
                 if key not in related_objects_for_fetch:
                     related_objects_for_fetch[key] = []
                 related_objects_for_fetch[key].append(getattr(instance, relation_key_field))
@@ -402,17 +405,17 @@ class BaseExecutor:
         return instance_list
 
     def _make_prefetch_queries(self) -> None:
-        for field, forwarded_prefetches in self.prefetch_map.items():
-            if field in self._prefetch_queries:
-                related_query = self._prefetch_queries[field]
+        for field_name, forwarded_prefetches in self.prefetch_map.items():
+            if field_name in self._prefetch_queries:
+                related_query = self._prefetch_queries[field_name]
             else:
-                related_model_field = self.model._meta.fields_map[field]
-                related_model: "Type[Model]" = related_model_field.model_class  # type: ignore
+                relation_field = self.model._meta.fields_map[field_name]
+                related_model: "Type[Model]" = relation_field.related_model  # type: ignore
                 related_query = related_model.all().using_db(self.db)
                 related_query.query = copy(related_query.model._meta.basequery)
             if forwarded_prefetches:
                 related_query = related_query.prefetch_related(*forwarded_prefetches)
-            self._prefetch_queries[field] = related_query
+            self._prefetch_queries[field_name] = related_query
 
     async def _do_prefetch(
         self, instance_id_list: "List[Model]", field: str, related_query: "QuerySet"
@@ -445,10 +448,12 @@ class BaseExecutor:
             first_level_field = relation_split[0]
             if first_level_field not in self.model._meta.fetch_fields:
                 raise OperationalError(
-                    f"relation {first_level_field} for {self.model._meta.table} not found"
+                    f"relation {first_level_field} for {self.model._meta.db_table} not found"
                 )
+
             if first_level_field not in self.prefetch_map.keys():
                 self.prefetch_map[first_level_field] = set()
+
             forwarded_prefetch = "__".join(relation_split[1:])
             if forwarded_prefetch:
                 self.prefetch_map[first_level_field].add(forwarded_prefetch)
